import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface OpenstackProviderConfig {
    /**
    * If set to `false`, OpenStack authorization won't be perfomed
    * automatically, if the initial auth token get expired. Defaults to `true`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#allow_reauth OpenstackProvider#allow_reauth}
    */
    readonly allowReauth?: boolean | cdktf.IResolvable;
    /**
    * Application Credential ID to login with.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#application_credential_id OpenstackProvider#application_credential_id}
    */
    readonly applicationCredentialId?: string;
    /**
    * Application Credential name to login with.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#application_credential_name OpenstackProvider#application_credential_name}
    */
    readonly applicationCredentialName?: string;
    /**
    * Application Credential secret to login with.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#application_credential_secret OpenstackProvider#application_credential_secret}
    */
    readonly applicationCredentialSecret?: string;
    /**
    * The Identity authentication URL.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#auth_url OpenstackProvider#auth_url}
    */
    readonly authUrl?: string;
    /**
    * A Custom CA certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#cacert_file OpenstackProvider#cacert_file}
    */
    readonly cacertFile?: string;
    /**
    * A client certificate to authenticate with.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#cert OpenstackProvider#cert}
    */
    readonly cert?: string;
    /**
    * An entry in a `clouds.yaml` file to use.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#cloud OpenstackProvider#cloud}
    */
    readonly cloud?: string;
    /**
    * The name of the Domain ID to scope to if no other domain is specified. Defaults to `default` (Identity v3).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#default_domain OpenstackProvider#default_domain}
    */
    readonly defaultDomain?: string;
    /**
    * If set to `false`, OpenStack authorization will be perfomed,
    * every time the service provider client is called. Defaults to `true`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#delayed_auth OpenstackProvider#delayed_auth}
    */
    readonly delayedAuth?: boolean | cdktf.IResolvable;
    /**
    * If set to `true`, the HTTP `Cache-Control: no-cache` header will not be added by default to all API requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#disable_no_cache_header OpenstackProvider#disable_no_cache_header}
    */
    readonly disableNoCacheHeader?: boolean | cdktf.IResolvable;
    /**
    * The ID of the Domain to scope to (Identity v3).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#domain_id OpenstackProvider#domain_id}
    */
    readonly domainId?: string;
    /**
    * The name of the Domain to scope to (Identity v3).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#domain_name OpenstackProvider#domain_name}
    */
    readonly domainName?: string;
    /**
    * Outputs very verbose logs with all calls made to and responses from OpenStack
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#enable_logging OpenstackProvider#enable_logging}
    */
    readonly enableLogging?: boolean | cdktf.IResolvable;
    /**
    * A map of services with an endpoint to override what was
    * from the Keystone catalog
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#endpoint_overrides OpenstackProvider#endpoint_overrides}
    */
    readonly endpointOverrides?: {
        [key: string]: string;
    };
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#endpoint_type OpenstackProvider#endpoint_type}
    */
    readonly endpointType?: string;
    /**
    * Trust self-signed certificates.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#insecure OpenstackProvider#insecure}
    */
    readonly insecure?: boolean | cdktf.IResolvable;
    /**
    * A client private key to authenticate with.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#key OpenstackProvider#key}
    */
    readonly key?: string;
    /**
    * How many times HTTP connection should be retried until giving up.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#max_retries OpenstackProvider#max_retries}
    */
    readonly maxRetries?: number;
    /**
    * Password to login with.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#password OpenstackProvider#password}
    */
    readonly password?: string;
    /**
    * The ID of the domain where the proejct resides (Identity v3).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#project_domain_id OpenstackProvider#project_domain_id}
    */
    readonly projectDomainId?: string;
    /**
    * The name of the domain where the project resides (Identity v3).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#project_domain_name OpenstackProvider#project_domain_name}
    */
    readonly projectDomainName?: string;
    /**
    * The OpenStack region to connect to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#region OpenstackProvider#region}
    */
    readonly region?: string;
    /**
    * Use Swift's authentication system instead of Keystone. Only used for
    * interaction with Swift.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#swauth OpenstackProvider#swauth}
    */
    readonly swauth?: boolean | cdktf.IResolvable;
    /**
    * If set to `true`, system scoped authorization will be enabled. Defaults to `false` (Identity v3).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#system_scope OpenstackProvider#system_scope}
    */
    readonly systemScope?: boolean | cdktf.IResolvable;
    /**
    * The ID of the Tenant (Identity v2) or Project (Identity v3)
    * to login with.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#tenant_id OpenstackProvider#tenant_id}
    */
    readonly tenantId?: string;
    /**
    * The name of the Tenant (Identity v2) or Project (Identity v3)
    * to login with.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#tenant_name OpenstackProvider#tenant_name}
    */
    readonly tenantName?: string;
    /**
    * Authentication token to use as an alternative to username/password.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#token OpenstackProvider#token}
    */
    readonly token?: string;
    /**
    * The ID of the domain where the user resides (Identity v3).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#user_domain_id OpenstackProvider#user_domain_id}
    */
    readonly userDomainId?: string;
    /**
    * The name of the domain where the user resides (Identity v3).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#user_domain_name OpenstackProvider#user_domain_name}
    */
    readonly userDomainName?: string;
    /**
    * User ID to login with.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#user_id OpenstackProvider#user_id}
    */
    readonly userId?: string;
    /**
    * Username to login with.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#user_name OpenstackProvider#user_name}
    */
    readonly userName?: string;
    /**
    * Alias name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#alias OpenstackProvider#alias}
    */
    readonly alias?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs openstack}
*/
export declare class OpenstackProvider extends cdktf.TerraformProvider {
    static readonly tfResourceType = "openstack";
    /**
    * Generates CDKTF code for importing a OpenstackProvider resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the OpenstackProvider to import
    * @param importFromId The id of the existing OpenstackProvider that should be imported. Refer to the {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the OpenstackProvider to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/terraform-provider-openstack/openstack/3.0.0/docs openstack} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options OpenstackProviderConfig = {}
    */
    constructor(scope: Construct, id: string, config?: OpenstackProviderConfig);
    private _allowReauth?;
    get allowReauth(): boolean | cdktf.IResolvable | undefined;
    set allowReauth(value: boolean | cdktf.IResolvable | undefined);
    resetAllowReauth(): void;
    get allowReauthInput(): boolean | cdktf.IResolvable | undefined;
    private _applicationCredentialId?;
    get applicationCredentialId(): string | undefined;
    set applicationCredentialId(value: string | undefined);
    resetApplicationCredentialId(): void;
    get applicationCredentialIdInput(): string | undefined;
    private _applicationCredentialName?;
    get applicationCredentialName(): string | undefined;
    set applicationCredentialName(value: string | undefined);
    resetApplicationCredentialName(): void;
    get applicationCredentialNameInput(): string | undefined;
    private _applicationCredentialSecret?;
    get applicationCredentialSecret(): string | undefined;
    set applicationCredentialSecret(value: string | undefined);
    resetApplicationCredentialSecret(): void;
    get applicationCredentialSecretInput(): string | undefined;
    private _authUrl?;
    get authUrl(): string | undefined;
    set authUrl(value: string | undefined);
    resetAuthUrl(): void;
    get authUrlInput(): string | undefined;
    private _cacertFile?;
    get cacertFile(): string | undefined;
    set cacertFile(value: string | undefined);
    resetCacertFile(): void;
    get cacertFileInput(): string | undefined;
    private _cert?;
    get cert(): string | undefined;
    set cert(value: string | undefined);
    resetCert(): void;
    get certInput(): string | undefined;
    private _cloud?;
    get cloud(): string | undefined;
    set cloud(value: string | undefined);
    resetCloud(): void;
    get cloudInput(): string | undefined;
    private _defaultDomain?;
    get defaultDomain(): string | undefined;
    set defaultDomain(value: string | undefined);
    resetDefaultDomain(): void;
    get defaultDomainInput(): string | undefined;
    private _delayedAuth?;
    get delayedAuth(): boolean | cdktf.IResolvable | undefined;
    set delayedAuth(value: boolean | cdktf.IResolvable | undefined);
    resetDelayedAuth(): void;
    get delayedAuthInput(): boolean | cdktf.IResolvable | undefined;
    private _disableNoCacheHeader?;
    get disableNoCacheHeader(): boolean | cdktf.IResolvable | undefined;
    set disableNoCacheHeader(value: boolean | cdktf.IResolvable | undefined);
    resetDisableNoCacheHeader(): void;
    get disableNoCacheHeaderInput(): boolean | cdktf.IResolvable | undefined;
    private _domainId?;
    get domainId(): string | undefined;
    set domainId(value: string | undefined);
    resetDomainId(): void;
    get domainIdInput(): string | undefined;
    private _domainName?;
    get domainName(): string | undefined;
    set domainName(value: string | undefined);
    resetDomainName(): void;
    get domainNameInput(): string | undefined;
    private _enableLogging?;
    get enableLogging(): boolean | cdktf.IResolvable | undefined;
    set enableLogging(value: boolean | cdktf.IResolvable | undefined);
    resetEnableLogging(): void;
    get enableLoggingInput(): boolean | cdktf.IResolvable | undefined;
    private _endpointOverrides?;
    get endpointOverrides(): {
        [key: string]: string;
    } | undefined;
    set endpointOverrides(value: {
        [key: string]: string;
    } | undefined);
    resetEndpointOverrides(): void;
    get endpointOverridesInput(): {
        [key: string]: string;
    } | undefined;
    private _endpointType?;
    get endpointType(): string | undefined;
    set endpointType(value: string | undefined);
    resetEndpointType(): void;
    get endpointTypeInput(): string | undefined;
    private _insecure?;
    get insecure(): boolean | cdktf.IResolvable | undefined;
    set insecure(value: boolean | cdktf.IResolvable | undefined);
    resetInsecure(): void;
    get insecureInput(): boolean | cdktf.IResolvable | undefined;
    private _key?;
    get key(): string | undefined;
    set key(value: string | undefined);
    resetKey(): void;
    get keyInput(): string | undefined;
    private _maxRetries?;
    get maxRetries(): number | undefined;
    set maxRetries(value: number | undefined);
    resetMaxRetries(): void;
    get maxRetriesInput(): number | undefined;
    private _password?;
    get password(): string | undefined;
    set password(value: string | undefined);
    resetPassword(): void;
    get passwordInput(): string | undefined;
    private _projectDomainId?;
    get projectDomainId(): string | undefined;
    set projectDomainId(value: string | undefined);
    resetProjectDomainId(): void;
    get projectDomainIdInput(): string | undefined;
    private _projectDomainName?;
    get projectDomainName(): string | undefined;
    set projectDomainName(value: string | undefined);
    resetProjectDomainName(): void;
    get projectDomainNameInput(): string | undefined;
    private _region?;
    get region(): string | undefined;
    set region(value: string | undefined);
    resetRegion(): void;
    get regionInput(): string | undefined;
    private _swauth?;
    get swauth(): boolean | cdktf.IResolvable | undefined;
    set swauth(value: boolean | cdktf.IResolvable | undefined);
    resetSwauth(): void;
    get swauthInput(): boolean | cdktf.IResolvable | undefined;
    private _systemScope?;
    get systemScope(): boolean | cdktf.IResolvable | undefined;
    set systemScope(value: boolean | cdktf.IResolvable | undefined);
    resetSystemScope(): void;
    get systemScopeInput(): boolean | cdktf.IResolvable | undefined;
    private _tenantId?;
    get tenantId(): string | undefined;
    set tenantId(value: string | undefined);
    resetTenantId(): void;
    get tenantIdInput(): string | undefined;
    private _tenantName?;
    get tenantName(): string | undefined;
    set tenantName(value: string | undefined);
    resetTenantName(): void;
    get tenantNameInput(): string | undefined;
    private _token?;
    get token(): string | undefined;
    set token(value: string | undefined);
    resetToken(): void;
    get tokenInput(): string | undefined;
    private _userDomainId?;
    get userDomainId(): string | undefined;
    set userDomainId(value: string | undefined);
    resetUserDomainId(): void;
    get userDomainIdInput(): string | undefined;
    private _userDomainName?;
    get userDomainName(): string | undefined;
    set userDomainName(value: string | undefined);
    resetUserDomainName(): void;
    get userDomainNameInput(): string | undefined;
    private _userId?;
    get userId(): string | undefined;
    set userId(value: string | undefined);
    resetUserId(): void;
    get userIdInput(): string | undefined;
    private _userName?;
    get userName(): string | undefined;
    set userName(value: string | undefined);
    resetUserName(): void;
    get userNameInput(): string | undefined;
    private _alias?;
    get alias(): string | undefined;
    set alias(value: string | undefined);
    resetAlias(): void;
    get aliasInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
